@@ -10,13 +10,17 @@ EXTENSIONS = {
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
+    'bazel': {'text', 'bazel'},
     'beancount': {'text', 'beancount'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
     'bzl': {'text', 'bazel'},
     'c': {'text', 'c'},
+    'c++': {'text', 'c++'},
+    'c++m': {'text', 'c++'},
     'cc': {'text', 'c++'},
+    'ccm': {'text', 'c++'},
     'cfg': {'text'},
     'chs': {'text', 'c2hs'},
     'cjs': {'text', 'javascript'},
@@ -28,6 +32,7 @@ EXTENSIONS = {
     'coffee': {'text', 'coffee'},
     'conf': {'text'},
     'cpp': {'text', 'c++'},
+    'cppm': {'text', 'c++'},
     'cr': {'text', 'crystal'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
@@ -40,6 +45,7 @@ EXTENSIONS = {
     'cue': {'text', 'cue'},
     'cuh': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
+    'cxxm': {'text', 'c++'},
     'cylc': {'text', 'cylc'},
     'dart': {'text', 'dart'},
     'dbc': {'text', 'dbc'},
@@ -54,7 +60,9 @@ EXTENSIONS = {
     'eps': {'binary', 'eps'},
     'erb': {'text', 'erb'},
     'erl': {'text', 'erlang'},
+    'ex': {'text', 'elixir'},
     'exe': {'binary'},
+    'exs': {'text', 'elixir'},
     'eyaml': {'text', 'yaml'},
     'f03': {'text', 'fortran'},
     'f08': {'text', 'fortran'},
@@ -66,6 +74,7 @@ EXTENSIONS = {
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'geojson': {'text', 'geojson', 'json'},
+    'ggb': {'binary', 'zip', 'ggb'},
     'gif': {'binary', 'image', 'gif'},
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
@@ -97,7 +106,8 @@ EXTENSIONS = {
     'inl': {'text', 'inl', 'c++'},
     'ino': {'text', 'ino', 'c++'},
     'inx': {'text', 'xml', 'inx'},
-    'ipynb': {'text', 'jupyter'},
+    'ipynb': {'text', 'jupyter', 'json'},
+    'ixx': {'text', 'c++'},
     'j2': {'text', 'jinja'},
     'jade': {'text', 'jade'},
     'jar': {'binary', 'zip', 'jar'},
@@ -238,6 +248,7 @@ EXTENSIONS = {
     'twig': {'text', 'twig'},
     'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
+    'txtpb': {'text', 'textproto'},
     'urdf': {'text', 'xml', 'urdf'},
     'v': {'text', 'verilog'},
     'vb': {'text', 'vb'},
@@ -258,6 +269,7 @@ EXTENSIONS = {
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
     'xhtml': {'text', 'xml', 'html', 'xhtml'},
+    'xacro': {'text', 'xml', 'urdf', 'xacro'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -284,6 +296,7 @@ EXTENSIONS_NEED_BINARY_CHECK = {
 }
 
 NAMES = {
+    '.ansible-lint': EXTENSIONS['yaml'],
     '.babelrc': EXTENSIONS['json'] | {'babelrc'},
     '.bash_aliases': EXTENSIONS['bash'],
     '.bash_profile': EXTENSIONS['bash'],
@@ -323,10 +336,12 @@ NAMES = {
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
     'BUILD': EXTENSIONS['bzl'],
-    'BUILD.bazel': EXTENSIONS['bzl'],
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
+    'config.ru': EXTENSIONS['rb'],
+    'Containerfile': {'text', 'dockerfile'},
     'CONTRIBUTING': EXTENSIONS['txt'],
+    'copy.bara.sky': EXTENSIONS['bzl'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
     'Gemfile': EXTENSIONS['rb'],
